@@ -1,8 +1,9 @@
 import re
 import shlex
 
-from mopidy.frontends.mpd.protocol import handle_request, stored_playlists
 from mopidy.frontends.mpd.exceptions import MpdArgError, MpdNotImplemented
+from mopidy.frontends.mpd.protocol import handle_request, stored_playlists
+from mopidy.frontends.mpd.translator import playlist_to_mpd_format
 
 def _build_query(mpd_query):
     """
@@ -68,7 +69,8 @@ def find(context, mpd_query):
     - also uses the search type "date".
     """
     query = _build_query(mpd_query)
-    return context.backend.library.find_exact(**query).get().mpd_format()
+    return playlist_to_mpd_format(
+        context.backend.library.find_exact(**query).get())
 
 @handle_request(r'^findadd '
      r'(?P<query>("?([Aa]lbum|[Aa]rtist|[Ff]ilename|[Tt]itle|[Aa]ny)"? '
@@ -187,8 +189,14 @@ def _list_build_query(field, mpd_query):
     """Converts a ``list`` query to a Mopidy query."""
     if mpd_query is None:
         return {}
-    # shlex does not seem to be friends with unicode objects
-    tokens = shlex.split(mpd_query.encode('utf-8'))
+    try:
+        # shlex does not seem to be friends with unicode objects
+        tokens = shlex.split(mpd_query.encode('utf-8'))
+    except ValueError as error:
+        if error.message == 'No closing quotation':
+            raise MpdArgError(u'Invalid unquoted character', command=u'list')
+        else:
+            raise error
     tokens = [t.decode('utf-8') for t in tokens]
     if len(tokens) == 1:
         if field == u'album':
@@ -324,7 +332,8 @@ def search(context, mpd_query):
     - also uses the search type "date".
     """
     query = _build_query(mpd_query)
-    return context.backend.library.search(**query).get().mpd_format()
+    return playlist_to_mpd_format(
+        context.backend.library.search(**query).get())
 
 @handle_request(r'^update( "(?P<uri>[^"]+)")*$')
 def update(context, uri=None, rescan_unmodified_files=False):
