@@ -1,20 +1,17 @@
-import unittest
-
-# FIXME Our Windows build server does not support GStreamer yet
 import sys
-if sys.platform == 'win32':
-    from tests import SkipTest
-    raise SkipTest
 
 from mopidy import settings
 from mopidy.backends.local import LocalBackend
 from mopidy.models import Track
 from mopidy.utils.path import path_to_uri
 
-from tests import path_to_data_dir
+from tests import unittest, path_to_data_dir
 from tests.backends.base.playback import PlaybackControllerTest
 from tests.backends.local import generate_song
 
+
+@unittest.skipIf(sys.platform == 'win32',
+    'Our Windows build server does not support GStreamer yet')
 class LocalPlaybackControllerTest(PlaybackControllerTest, unittest.TestCase):
     backend_class = LocalBackend
     tracks = [Track(uri=generate_song(i), length=4464)
@@ -36,8 +33,8 @@ class LocalPlaybackControllerTest(PlaybackControllerTest, unittest.TestCase):
         track = Track(uri=uri, length=4464)
         self.backend.current_playlist.add(track)
 
-    def test_uri_handler(self):
-        self.assert_('file://' in self.backend.uri_handlers)
+    def test_uri_scheme(self):
+        self.assert_('file' in self.backend.uri_schemes)
 
     def test_play_mp3(self):
         self.add_track('blank.mp3')
